Changelog
~~~~~~~~~

0.16.0 (November 2021)
----------------------

* Updated pytket version requirement to 0.17.

0.15.0 (October 2021)
---------------------

* Updated pytket version requirement to 0.16.

0.14.0 (September 2021)
-----------------------

* Updated pytket version requirement to 0.15.

0.13.0 (September 2021)
-----------------------

* Updated projectq version requirement to 0.7.
* Updated pytket version requirement to 0.14.

0.12.0 (July 2021)
------------------

* Updated pytket version requirement to 0.13.

0.11.1 (unreleased)
-------------------

* Updated projectq version requirement to 0.6.

0.11.0 (June 2021)
------------------

* Updated pytket version requirement to 0.12.

0.10.0 (May 2021)
-----------------

* Updated pytket version requirement to 0.11.
